pub struct SdJwt { /* private fields */ }Expand description
Representation of an SD-JWT of the format
<Issuer-signed JWT>~<D.1>~<D.2>~...~<D.N>~<optional KB-JWT>.
Implementations
Sourceimpl SdJwt
impl SdJwt
pub fn headers(&self) -> &JsonObject
pub fn claims(&self) -> &SdJwtClaims
Sourcepub fn claims_mut(&mut self) -> &mut SdJwtClaims
pub fn claims_mut(&mut self) -> &mut SdJwtClaims
Returns a mutable reference to this SD-JWT’s claims.
Warning
Modifying the claims might invalidate the signature. Use this method carefully.
Sourcepub fn disclosures(&self) -> &[Disclosure]
pub fn disclosures(&self) -> &[Disclosure]
Returns the disclosures of this SD-JWT.
Sourcepub fn required_key_bind(&self) -> Option<&RequiredKeyBinding>
pub fn required_key_bind(&self) -> Option<&RequiredKeyBinding>
Returns the required key binding of this SD-JWT, if any.
Sourcepub fn key_binding_jwt(&self) -> Option<&KeyBindingJwt>
pub fn key_binding_jwt(&self) -> Option<&KeyBindingJwt>
Returns the key binding JWT of this SD-JWT, if any.
Sourcepub fn attach_key_binding_jwt(&mut self, kb_jwt: KeyBindingJwt)
pub fn attach_key_binding_jwt(&mut self, kb_jwt: KeyBindingJwt)
Attaches a KeyBindingJwt to this SD-JWT.
Notes
This method overwrites any existing KeyBindingJwt and does not perform any sort of validation of the passed KB-JWT.
Sourcepub fn presentation(&self) -> String
pub fn presentation(&self) -> String
Serializes the components into the final SD-JWT.
Sourcepub fn into_presentation(
self,
hasher: &dyn Hasher,
) -> Result<SdJwtPresentationBuilder>
pub fn into_presentation( self, hasher: &dyn Hasher, ) -> Result<SdJwtPresentationBuilder>
Prepares this SdJwt for a presentation, returning an SdJwtPresentationBuilder.
Errors
Error::InvalidHasheris returned if the providedhasher’s algorithm doesn’t match the algorithm specified by SD-JWT’s_sd_algclaim. “sha-256” is used if the claim is missing.
Sourcepub fn into_disclosed_object(self, hasher: &dyn Hasher) -> Result<JsonObject>
pub fn into_disclosed_object(self, hasher: &dyn Hasher) -> Result<JsonObject>
Returns the JSON object obtained by replacing all disclosures into their corresponding JWT concealable claims.